@@ -29,7 +29,7 @@ import errno
 import dateutil.parser as parser
 from datetime import timedelta
 import logging
-from owslib.util import log, datetime_from_ansi, datetime_from_iso
+from owslib.util import log, datetime_from_ansi, datetime_from_iso, param_list_to_url_string
 
 
 #  function to save writing out WCS namespace in full each time
@@ -113,14 +113,6 @@ class WebCoverageService_2_0_1(WCSBase):
             items.append((item, self.contents[item]))
         return items
 
-    def __makeString(self, value):
-        # using repr unconditionally breaks things in some circumstances if a value is already a string
-        if type(value) is not str:
-            sval = repr(value)
-        else:
-            sval = value
-        return sval
-
     def getCoverage(
         self,
         identifier=None,
@@ -128,6 +120,8 @@ class WebCoverageService_2_0_1(WCSBase):
         time=None,
         format=None,
         subsets=None,
+        resolutions=None,
+        sizes=None,
         crs=None,
         width=None,
         height=None,
@@ -188,8 +182,7 @@ class WebCoverageService_2_0_1(WCSBase):
         except StopIteration:
             base_url = self.url
 
-        if log.isEnabledFor(logging.DEBUG):
-            log.debug("WCS 2.0.1 DEBUG: base url of server: %s" % base_url)
+        log.debug("WCS 2.0.1 DEBUG: base url of server: %s" % base_url)
 
         request = {"version": self.version, "request": "GetCoverage", "service": "WCS"}
         assert len(identifier) > 0
@@ -211,42 +204,19 @@ class WebCoverageService_2_0_1(WCSBase):
         # encode and request
         data = urlencode(request)
         if subsets:
-            for subset in subsets:
-                if len(subset) > 2:
-                    if not self.is_number(subset[1]):
-                        data = (
-                            data + "&" + urlencode({"subset": subset[0] + '("' + self.__makeString(subset[1]) + '","' + self.__makeString(subset[2]) + '")'})  # noqa
-                        )
-                    else:
-                        data = (
-                            data + "&" + urlencode({"subset": subset[0] + "(" + self.__makeString(subset[1]) + "," + self.__makeString(subset[2]) + ")"})  # noqa
-                        )
-                else:
-                    if not self.is_number(subset[1]):
-                        data = (
-                            data + "&" + urlencode({"subset": subset[0] + '("' + self.__makeString(subset[1]) + '")'})
-                        )
-                    else:
-                        data = (
-                            data + "&" + urlencode({"subset": subset[0] + "(" + self.__makeString(subset[1]) + ")"})
-                        )
+            data += param_list_to_url_string(subsets, 'subset')
+        if resolutions:
+            log.debug('Adding vendor-specific RESOLUTION parameter.')
+            data += param_list_to_url_string(resolutions, 'resolution')
+        if sizes:
+            log.debug('Adding vendor-specific SIZE parameter.')
+            data += param_list_to_url_string(sizes, 'size')
 
-        if log.isEnabledFor(logging.DEBUG):
-            log.debug("WCS 2.0.1 DEBUG: Second part of URL: %s" % data)
+        log.debug("WCS 2.0.1 DEBUG: Second part of URL: %s" % data)
 
         u = openURL(base_url, data, method, self.cookies, auth=self.auth)
         return u
 
-    def is_number(self, s):
-        """simple helper to test if value is number as requests with numbers dont
-        need quote marks
-        """
-        try:
-            float(s)
-            return True
-        except ValueError:
-            return False
-
     def getOperationByName(self, name):
         """Return a named operation item."""
         for item in self.operations:
